#
# spec file for package python-Markdown
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%endif
%if "%{flavor}" == ""
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-Markdown%{psuffix}
Version:        3.8.2
Release:        1.1
Summary:        Python implementation of Markdown
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://python-markdown.github.io/
Source:         https://files.pythonhosted.org/packages/source/m/markdown/markdown-%{version}.tar.gz
Patch0:         markdown-3.0-python37.patch
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module importlib-metadata >= 4.4 if %python-base < 3.10}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module Markdown = %{version}}
BuildRequires:  %{python_module PyYAML}
%endif
Requires:       (python-importlib-metadata >= 4.4 if python-base < 3.10)
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This is a Python implementation of John Gruber's [Markdown][].
It is almost completely compliant with the reference implementation,
though there are a few known issues. See [Features][] for information
on what exactly is supported and what is not. Additional features are
supported by the [Available Extensions][].

%prep
%autosetup -p1 -n markdown-%{version}

%build
%if %{without test}
%pyproject_wheel
%endif

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/markdown_py
%endif

%check
%if %{with test}
%pyunittest discover -v
%endif

%if %{without test}
%post
%python_install_alternative markdown_py

%postun
%python_uninstall_alternative markdown_py

%files %{python_files}
%license LICENSE.md
%doc README.md docs/*
%python_alternative %{_bindir}/markdown_py
%{python_sitelib}/markdown
%{python_sitelib}/[mM]arkdown-%{version}.dist-info
%endif

%changelog
* Thu Jun 19 2025 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.8.2:
  * Fix codecs deprecation in Python 3.14.
  * Fix issue with unclosed comment parsing in Python 3.14.
  * Fix issue with unclosed declarations in Python 3.14.
  * Fix issue with unclosed HTML tag <foo and Python 3.14.
* Wed Jun 18 2025 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.8.1:
  * Ensure incomplete markup declaration in raw HTML doesn’t crash
    parser (#1534).
  * Fixed dropped content in md_in_html (#1526).
  * Fixed HTML handling corner case that prevented some content
    from not being rendered (#1528).
* Fri Apr 11 2025 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.8:
  * Changed
    + DRY fix in abbr extension by introducing method
    create_element (#1483).
    + Clean up test directory by removing some redundant tests and
    port non-redundant cases to the newer test framework.
    + Improved performance of the raw HTML post-processor (#1510).
  * Fixed
    + Backslash Unescape IDs set via attr_list on toc (#1493).
    + Ensure md_in_html processes content inside “markdown” blocks
    as they are parsed outside of “markdown” blocks to keep
    things more consistent for third-party extensions (#1503).
    + md_in_html handle tags within inline code blocks better
    (#1075).
    + md_in_html fix handling of one-liner block HTML handling
    (#1074).
    + Ensure <center> is treated like a block-level element
    (#1481).
    + Ensure that abbr extension respects AtomicString and does not
    process perceived abbreviations in these strings (#1512).
    + Ensure smarty extension correctly renders nested closing
    quotes (#1514).
* Tue Apr  1 2025 Markéta Machová <mmachova@suse.com>
- Make the metadata directory name case-insensitive.
* Tue Mar 25 2025 Steve Kowalik <steven.kowalik@suse.com>
- Lowercase metadata directory name.
* Sat Aug 17 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.7:
  * Changed
    + Refactor abbr Extension
  * Fixed
    + Fixed links to source code on GitHub from the documentation
    (#1453).
- rename source tarball to markdown to match upstream
* Mon Aug 12 2024 Matej Cepl <mcepl@cepl.eu>
- Split the package into multibuild with tests separate (to
  separate PyYAML dependency).
* Fri Mar 15 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.6:
  * Changed
    + Refactor TOC Sanitation
  * Fixed
    + Include scripts/*.py in the generated source tarballs (#1430)
    + Ensure lines after heading in loose list are properly
    detabbed (#1443).
    + Give smarty tree processor higher priority than toc (#1440).
    + Permit carets (^) and square brackets (]) but explicitly
    exclude backslashes (\) from abbreviations (#1444).
    + In attribute lists (attr_list, fenced_code), quoted attribute
    values are now allowed to contain curly braces (}) (#1414).
* Thu Jan 11 2024 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.5.2:
  * Fix type annotations for convertFile - it accepts only
    bytes-based buffers. Also remove legacy checks from Python 2
    (#1400)
  * Remove legacy import needed only in Python 2 (#1403)
  * Fix typo that left the attribute
    AdmonitionProcessor.content_indent unset (#1404)
  * Fix edge-case crash in InlineProcessor with AtomicString
    (#1406).
  * Fix edge-case crash in codehilite with an empty code tag
    (#1405).
  * Improve and expand type annotations in the code base (#1401).
  * Fix handling of bogus comments (#1425).
* Wed Nov  1 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.5.1:
  * Fix a performance problem with HTML extraction where large HTML
    input could trigger quadratic line counting behavior (#1392).
  * Improve and expand type annotations in the code base (#1394).
* Sun Oct  8 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.5:
  * Added:
    + Add permalink_leading configuration option to the toc
    extension (#1339)
  * Changed:
    + Add support for cPython version 3.12 (and PyPy 3.10) and drop
    support for Python version 3.7 (#1357).
    + Refactor changelog to use the format defined at
    https://keepachangelog.com/.
    + Update the list of empty HTML tags (#1353).
    + Add customizable TOC title class to TOC extension (#1293).
    + Add API documentation of the code base which is generated by
    mkdocstrings (#1220).
  * Fixed:
    + Fix a corner case in admonitions where if an indented code
    block was provided as the first block, the output would be
    malformed (#1329).
- set the minimum python version to 3.8
* Tue Jul 25 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.4.4: bug-fix release
  * Add a special case for initial 's to smarty extension (#1305).
  * Unescape any backslash escaped inline raw HTML (#1358).
  * Unescape backslash escaped TOC token names (#1360).
* Tue Jun 20 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Mar 24 2023 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.4.3: bug-fix release
  * Restore console script (#1327).
- additional changes from version 3.4.2: bug-fix release
  * Improve standalone * and _ parsing (#1300).
  * Consider <html> HTML tag a block-level element (#1309).
  * Officially support Python 3.11.
  * Switch from setup.py to pyproject.toml.
- drop macros in spec file: already provided by python-rpm-macros
* Sun Jul 17 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.4.1: bug-fix release
  * Fix an import issue with importlib.util (#1274).
- additional changes from version 3.4.0:
  * see https://python-markdown.github.io/change_log/release-3.4/
    for details
- drop requirement of python-xml, not needed by upstream
- set the minimum python version to 3.7
- require importlib-metadata only for python version < 3.10
* Thu May  5 2022 Matej Cepl <mcepl@suse.com>
- Clean up the SPEC file.
* Thu May  5 2022 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.3.7: bug-fix release
  * Disallow square brackets in reference link ids (#1209)
  * Retain configured pygments_style after first code block (#1240)
  * Ensure fenced code attributes are properly escaped (#1247)
* Wed Nov 24 2021 Dirk Müller <dmueller@suse.com>
- update to 3.3.6:
  * Fix a dependency issue
* Tue Nov 16 2021 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.3.5: bug-fix release
  * Make the slugify_unicode function not remove diacritical marks
    (#1118).
  * Fix [toc] detection when used with nl2br extension (#1160).
  * Re-use compiled regex for block level checks (#1169).
  * Don't process shebangs in fenced code blocks when using
    CodeHilite (#1156).
  * Improve email address validation for Automatic Links (#1165).
  * Ensure <summary> tags are parsed correctly (#1079).
  * Support Python 3.10 (#1124).
* Thu Feb 25 2021 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.3.4: bug-fix release
  * Properly parse unclosed tags in code spans (#1066)
  * Properly parse processing instructions in md_in_html (#1070)
  * Properly parse code spans in md_in_html (#1069)
  * Preserve text immediately before an admonition (#1092)
  * Simplified regex for HTML placeholders (#928) addressing (#932)
  * Ensure permalinks and anchorlinks are not restricted by
    toc_depth (#1107)
* Sun Oct 25 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.3.3: bug-fix release
  * Unify all block-level tags (#1047).
  * Fix issue where some empty elements would have text rendered
    as None when using md_in_html (#1049).
  * Avoid catastrophic backtracking in hr regex (#1055).
  * Fix hr HTML handling (#1053).
* Tue Oct 20 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.3.2: bug-fix release
  * Properly parse inline HTML in md_in_html (#1040 & #1045).
  * Avoid crashing when md_in_html fails (#1040).
* Tue Oct 13 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.3.1: bug-fix release
  * Correctly parse raw script and style tags (#1036).
  * Ensure consistent class handling by fenced_code and codehilite
    (#1032).
* Wed Oct  7 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.3: major release
  see https://python-markdown.github.io/change_log/release-3.3/
  for details
* Sat May  9 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.2.2:
  * Add checklinks tox environment to ensure all links in
    documentation are good.
  * Refactor extension API documentation (#729).
  * Load entry_points (for extensions) only once using
    importlib.metadata.
  * Do not double escape entities in TOC.
  * Correctly report if an extension raises a TypeError (#939).
  * Raise a KeyError when attempting to delete a nonexistent key
    from the extension registry (#939).
  * Remove import of packaging (or pkg_resources fallback) entirely
  * Remove setuptools as a run-time dependency (install_required).
- add new requirement importlib-metadata for python < 3.8
- remove setuptools from Requires: dependency dropped by upstream
* Thu Feb 13 2020 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.2.1: bugfix release
  * The name property in toc_tokens from the TOC extension now
    escapes HTML special characters (<, >, and &).
- additional changes from version 3.2: major release
  * Backwards-incompatible changes:
    + Drop support for Python 2.7
    + em and strong inline processor changes
    + CodeHilite now always wraps with <code> tags
    + markdown.util.etree deprecated
  * New features:
    + Some new configuration options have been added to the toc
    extension
    + Document thread safety (#812).
    + Markdown parsing in HTML has been exposed via a separate
    extension called md_in_html.
    + Add support for Python 3.8.
  * Bug fixes:
    + HTML tag placeholders are no longer included in .toc_tokens
    (#899).
    + Unescape backslash-escaped characters in TOC ids (#864).
    + Refactor bold and italic logic in order to solve complex
    nesting issues (#792).
    + Always wrap CodeHilite code in tags (#862).
- disable python2 build: Markdown is python 3 only now
* Tue May 21 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.1.1: bugfix release
  * Fixed import failure in setup.py when the source directory is
    not on sys.path (#823).
  * Prefer public packaging module to pkg_resources' private copy
    of it (#825).
* Tue Mar 26 2019 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.1:
  * The following new features have been included in the release:
    + A Contributing Guide has been added (#732)
    + A new configuration option to set the footnote separator has
    been added. Also, the rel and rev attributes have been
    removed from footnotes as they are not valid in HTML5. The
    refs and backrefs classes already exist and serve the same
    purpose (#723).
    + A new option for toc_depth to set not only the bottom section
    level, but also the top section level. A string consisting of
    two digits separated by a hyphen in between ("2-5"), defines
    the top (t) and the bottom (b) (<ht>..<hb>). A single integer
    still defines the bottom section level (<h1>..<hb>) only.(#787)
  * The following bug fixes are included in the 3.1 release:
    + Update CLI to support PyYAML 5.1.
    + Overlapping raw HTML matches no longer leave placeholders
    behind (#458).
    + Emphasis patterns now recognize newline characters as
    whitespace (#783).
    + Version format had been updated to be PEP 440 compliant
    (#736).
    + Block level elements are defined per instance, not as class
    attributes (#731).
    + Double escaping of block code has been eliminated (#725).
    + Problems with newlines in references has been fixed (#742).
    + Escaped # are now handled in header syntax (#762).
- remove yaml5.patch: merged upstream
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix build with PyYAML > 5:
  * yaml5.patch
* Wed Jan  2 2019 badshah400@gmail.com
- Update to version 3.0.1:
  * Brought back the `version` and `version_info` variables
    (gh#Python-Markdown/markdown#709).
  * Added support for hexadecimal HTML entities
    (gh#Python-Markdown/markdown#712).
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Thu Oct 18 2018 Benoît Monin <benoit.monin@gmx.fr>
- update to version 3.0: major release
  * backwards-incompatible changes:
    + enable_attributes keyword deprecated
    + smart_emphasis keyword and smart_strong extension deprecated
    + output_formats simplified to html and xhtml
    + safe_mode and html_replacement_text keywords deprecated
    + Positional arguments deprecated
    + Extension name behavior has changed
    + Extension configuration as part of extension name deprecated
    + HeaderId extension deprecated
    + Homegrown OrderedDict has been replaced with a purpose-built
    Registry
    + Markdown class instance references
    + markdown.util.isBlockLevel deprecated
    + md_globals keyword deprecated from extension API
    + Added new, more flexible InlineProcessor class
  * new features:
    + a new testing framework is included as a part of the Markdown
    library, which can also be used by third party extensions
    + a new toc_depth parameter has been added to the Table of
    Contents Extension
    +  new toc_tokens attribute has been added to the Markdown class
    by the Table of Contents Extension
    + when the Table of Contents Extension is used in conjunction
    with the Attribute Lists Extension and a data-toc-label
    attribute is defined on a header, the content of the
    data-toc-label attribute is now used as the content of the
    Table of Contents item for that header
    + additional CSS class names can be appended to Admonitions
- update and adapt the patch for python-3.7:
  * add markdown-3.0-python37.patch
  * remove markdown-2.6.11-python37.patch
- run the tests via unittest discover
- remove nose from BuildRequires: not used anymore
* Tue Aug  7 2018 tchvatal@suse.com
- Add patch to build with python 3.7:
  * markdown-2.6.11-python37.patch
* Mon Mar 19 2018 tchvatal@suse.com
- Add build/runtime dependency over setuptools wrt bsc#1079287
- Remove python-devel dependency which is not really needed
* Fri Jan  5 2018 benoit.monin@gmx.fr
- update to version 2.6.11: bugfix release
  * Added a new BACKLINK-TITLE option to the footnote extension so
    that non-English users can provide a custom title to back links
    (see #610)
- additional changes from version 2.6.10: documentation update
- remove encoding conversion: fixed upstream
* Fri Aug 18 2017 benoit.monin@gmx.fr
- update to version 2.6.9: bugfix release
* Sun May  7 2017 benoit.monin@gmx.fr
- convert the package to singlespec
- call fdupes to fix duplicated files
- fix encoding of the single file with CR/LF:
  avoid python-bytecode-inconsistent-mtime in every other files
* Thu Jan 26 2017 benoit.monin@gmx.fr
- update to version 2.6.8: bugfix release
* Sat Sep 24 2016 benoit.monin@gmx.fr
- update to version 2.6.7: bugfix release
- change source url to files.pythonhosted.org
* Wed Mar 23 2016 benoit.monin@gmx.fr
- update to version 2.6.6: no upstream changelog
* Wed Nov 25 2015 benoit.monin@gmx.fr
- update to version 2.6.5: bugfix release
* Sat Nov  7 2015 benoit.monin@gmx.fr
- update to version 2.6.4: bugfix release
* Tue Oct 27 2015 benoit.monin@gmx.fr
- update to version 2.6.3: bugfix release
* Tue Apr 21 2015 benoit.monin@gmx.fr
- update to version 2.6.2: bugfix release
* Tue Mar 10 2015 benoit.monin@gmx.fr
- update to version 2.6.1: bugfix release
  The (new) yaml option has been removed from the Meta-Data
  Extension as it was buggy
* Fri Feb 20 2015 benoit.monin@gmx.fr
- update to version 2.6:
  * `safe_mode` Deprecated
  * Positional Arguments Deprecated
  * "Shortened" Extension Names Deprecated
  * Extension Configuration as Part of Extension Name Deprecated
  * HeaderId Extension Pending Deprecation
  * The `configs` Keyword is Deprecated
  * Official Support for PyPy
  * YAML Style Meta-Data
  * Table of Contents Extension Refactored
  * Pygments can now be disabled
  * Miscellaneous
* Mon Nov 24 2014 benoit.monin@gmx.fr
- update to version 2.5.2: bugfix release
* Fri Oct  3 2014 benoit.monin@gmx.fr
- update to version 2.5.1: bugfix release
* Tue Sep 16 2014 benoit.monin@gmx.fr
- update to version 2.5:
  * The force_linenos config key on the CodeHilite extension has
    been deprecated.
  * Both safe_mode and the associated html_replacement_text
    keywords will be deprecated in version 2.6.
  * Positional arguments on the markdown.Markdown() function are
    pending deprecation.
  * The builtin extensions did not require the full path to be
    provided. This behavior will be deprecated in version 2.6.
  * The previously documented method of appending the extension
    configs as a string to the extension name will be deprecated in
    version 2.6.
  * The Smarty extension has had a number of additional
    configuration settings added.
  * Named extensions can now point to any module and/or Class on
    your PYTHONPATH.
  * The extension configuration code has been refactored.
  * The command line interface now accepts a --extensions_config
    (or -c).
  * The amonition extension is no longer considered experimental.
  * Various bug fixes have been made.
- add python-PyYAML to BuildRequires: needed for tests
* Wed Jul  9 2014 i@marguerite.su
- fix conflicts with python3-Markdown
  * both use update-alternatives
* Mon May 26 2014 hpj@urpla.net
- disable tests for 11.1 and SLES 10 builds
* Mon Feb 17 2014 benoit.monin@gmx.fr
- update to version 2.4:
  * the "force_linenos" config setting of the CodeHilite extension
    has been marked as Deprecated.
  * URLs are no longer percent-encoded.
  * the Smarty Extension has been added, which implements
    SmartyPants.
  * the Table of Contents Extension now supports new permalink
    option for creating Sphinx-style anchor links.
  * it is now possible to enable Markdown formatting inside HTML
    blocks by appending `markdown=1` to opening tag attributes.
  * The code blocks now support emphasizing some of the code lines.
  * Various bug fixes have been made.
- fix CRLF in all files: upstream converted to DOS encoding
* Wed Jan 15 2014 benoit.monin@gmx.fr
- update to version 2.3.1:
  no changelog
- additional changes from version 2.3.0:
  * Support has been dropped for Python 2.5.
  * All classes are now "new-style" classes.
  * "safe_mode" has been further restricted.
  * The ids assigned to footnotes now contain a dash (`-`) rather
    than a colon (`:`) when `output_format` it set to "html5" or
    "xhtml5".
  * The "force_linenos" config setting of the CodeHilite extension
    has been marked as Pending Deprecation and a new setting
    "linenums" has been added to replace it.
  * The "RSS" extension has been removed.
  * The "HTML Tidy" Extension has been removed.
  * The entire code base now universally runs in Python 2 and
    Python 3 without any need for running the 2to3 conversion tool.
  * The Admonition Extension has been added.
  * Various bug fixes have been made.
- drop sed call to remove shebangs: fixed upstream
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 2.2.1:
  + Python-Markdown 2.2.1 is a bug-fix release. No new features have been added.
    However, at least one bug fix does not work in Python 2.4 so that version of
    Python is no longer supported. For a full list of changes, see the git log.
* Mon Jul 23 2012 saschpe@suse.de
- Initial version
